@@ -1,5 +1,5 @@
 class ModelGenerator < Rails::Generator::NamedBase
-  default_options :skip_migration => false
+  default_options :skip_timestamps => false, :skip_migration => false, :skip_fixture => false
 
   def manifest
     record do |m|
@@ -14,7 +14,10 @@ class ModelGenerator < Rails::Generator::NamedBase
       # Model class, unit test, and fixtures.
       m.template 'model.rb',      File.join('app/models', class_path, "#{file_name}.rb")
       m.template 'unit_test.rb',  File.join('test/unit', class_path, "#{file_name}_test.rb")
-      m.template 'fixtures.yml',  File.join('test/fixtures', class_path, "#{table_name}.yml")
+
+      unless options[:skip_fixture] 
+       	m.template 'fixtures.yml',  File.join('test/fixtures', "#{table_name}.yml")
+      end
 
       unless options[:skip_migration]
         m.migration_template 'migration.rb', 'db/migrate', :assigns => {
@@ -25,10 +28,18 @@ class ModelGenerator < Rails::Generator::NamedBase
   end
 
   protected
+    def banner
+      "Usage: #{$0} #{spec.name} ModelName [field:type, field:type]"
+    end
+
     def add_options!(opt)
       opt.separator ''
       opt.separator 'Options:'
+      opt.on("--skip-timestamps",
+             "Don't add timestamps to the migration file for this model") { |v| options[:skip_timestamps] = v }
       opt.on("--skip-migration", 
              "Don't generate a migration file for this model") { |v| options[:skip_migration] = v }
+      opt.on("--skip-fixture",
+             "Don't generation a fixture file for this model") { |v| options[:skip_fixture] = v}
     end
 end
